pub enum Alterer<C: Chromosome> {
Mutate(&'static str, Rate, Arc<dyn Mutate<C>>),
Crossover(&'static str, Rate, Arc<dyn Crossover<C>>),
}Expand description
The Alterer enum is used to represent the different types of alterations that can be performed on a population - It can be either a mutation or a crossover operation.
Variants
Mutate(&'static str, Rate, Arc<dyn Mutate<C>>)
Crossover(&'static str, Rate, Arc<dyn Crossover<C>>)
Implementations