pub struct Alterer<C: Chromosome> { /* private fields */ }Expand description
The Alterer struct is used to represent the different types of alterations that can be performed on a population - It can be either a mutation or a crossover operation.
Implementations
Sourceimpl<C: Chromosome> Alterer<C>
impl<C: Chromosome> Alterer<C>
pub fn mutation(name: &'static str, rate: Rate, m: Arc<dyn Mutate<C>>) -> Self
pub fn crossover( name: &'static str, rate: Rate, c: Arc<dyn Crossover<C>>, ) -> Self
pub fn rate(&self) -> &Rate
pub fn name(&self) -> &str
pub fn alter( &mut self, population: &mut [Phenotype<C>], metrics: &mut MetricSet, generation: usize, )