Module char

Module char 

Structs

CharCodec
A Codec for a Genotype of CharGenes. The encode function creates a Genotype with num_chromosomes chromosomes and num_genes genes per chromosome. The decode function creates a String from the Genotype where the String contains the alleles of the CharGenes in the chromosome.