FloatCodec

Struct FloatCodec 

pub struct FloatCodec<F: Float, T = F> { /* private fields */ }
A Codec for a Genotype of FloatGenes. The encode function creates a Genotype with num_chromosomes chromosomes and num_genes genes per chromosome. The decode function creates a Vec<Vec<f32>> from the Genotype where the inner Vec contains the alleles of the FloatGenes in the chromosome - the f32 values.

The lower and upper bounds of the FloatGenes can be set with the with_bounds function. The default bounds are equal to min and max values.

Implementations

Source

impl<F: Float, T> FloatCodec<F, T>

pub fn with_bounds(self, range: Range<F>) -> Self

Set the bounds of the FloatGenes in the Genotype. The default bounds are equal to the min and max values.

Source

impl<F: Float> FloatCodec<F, Vec<Vec<Vec<F>>>>

pub fn tensor(shapes: Vec<(usize, usize)>, range: Range<F>) -> Self

Source

impl<F: Float> FloatCodec<F, Vec<Vec<F>>>

pub fn matrix(rows: usize, cols: usize, range: Range<F>) -> Self

Create a new FloatCodec with the given number of chromosomes, genes, min, and max values. The f_32 values for each FloatGene will be randomly generated between the min and max values.

Source

impl<F: Float> FloatCodec<F, Vec<F>>

pub fn vector(count: usize, range: Range<F>) -> Self

Create a new FloatCodec with the given number of chromosomes, genes, min, and max values. The f_32 values for each FloatGene will be randomly generated between the min and max values.

Source

impl FloatCodec<f32>

pub fn scalar(range: Range<f32>) -> Self

Create a new FloatCodec with the given number of chromosomes, genes, min, and max values. The f_32 values for each FloatGene will be randomly generated between the min and max values.