Structs
- SubSet
Codec - A
Codecfor a subset of items. This is useful for problems where the goal is to find the best subset of items from a larger set of items. Theencodefunction creates aGenotypewith a single chromosome ofBitGeneswhere each gene represents an item in theitemsvector. Thedecodefunction creates aVec<&T>from theGenotypewhere theVeccontains the items that are selected by theBitGenes- thetruegenes.