EuclideanDistance

Struct EuclideanDistance 

pub struct EuclideanDistance;
Implementation of the Diversity trait that calculates the Euclidean distance between two [Genotype]s. The Euclidean distance is the square root of the sum of the squared differences between the corresponding genes’ alleles, normalized by the number of genes.