Module sync

Module sync 

Structs

CommandChannel
MutCell
WaitGroup
WaitGuard
WorkResult
WorkResult is a simple wrapper around a Receiver that allows the user to get the result of a job that was executed in the thread pool. It kinda acts like a Future in a synchronous way.

Traits

ArcExt

Functions

get_thread_pool