WorkResult

Struct WorkResult 

pub struct WorkResult<T> { /* private fields */ }
WorkResult is a simple wrapper around a Receiver that allows the user to get the result of a job that was executed in the thread pool. It kinda acts like a Future in a synchronous way.

Implementations

Source

impl<T> WorkResult<T>

pub fn new(rx: Receiver<T>) -> Self

pub fn result(&self) -> T

Get the result of the job. Note: This method will block until the result is available.