Struct ThreadPool

pub struct ThreadPool { /* private fields */ }

Implementations

Source

impl ThreadPool

pub fn new(size: usize) -> Self

Basic thread pool implementation.

Create a new ThreadPool with the given size.

pub fn group_submit(&self, wg: &WaitGroup, f: impl FnOnce() + Send + 'static)

pub fn submit<F>(&self, f: F)
where F: FnOnce() + Send + 'static,

Execute a job in the thread pool. This is a ‘fire and forget’ method.

pub fn submit_with_result<F, T>(&self, f: F) -> WorkResult<T>
where F: FnOnce() -> T + Send + 'static, T: Send + 'static,

Execute a job in the thread pool and return a WorkResult that can be used to get the result of the job.

pub fn num_workers(&self) -> usize

pub fn is_alive(&self) -> bool