pub struct Front<T>where
T: Scored,{ /* private fields */ }Expand description
A Front<T> is a collection of T’s that are non-dominated with respect to each other.
This is useful for multi-objective optimization problems where the goal is to find
the best solutions that are not dominated by any other solution.
This results in what is called the Pareto front.
Implementations
Sourceimpl<T> Front<T>where
T: Scored,
impl<T> Front<T>where
T: Scored,
pub fn new(range: Range<usize>, objective: Objective) -> Self
pub fn range(&self) -> Range<usize>
pub fn objective(&self) -> Objective
pub fn is_empty(&self) -> bool
pub fn values(&self) -> &[Arc<T>]
pub fn crowding_distance(&self) -> Option<Vec<f32>>
pub fn entropy(&self) -> Option<f32>
pub fn add_all(&mut self, items: &[T]) -> FrontAddResult