Module problem

Structs

EngineProblem
EngineProblem is a generic, base level concrete implementation of the Problem trait that is the default problem used by the engine if none other is specified during building. We take the Codec and the fitness function from the user and simply wrap them into this struct.

Traits

Problem
Problem represents the interface for the fitness function or evaluation and encoding/decoding of a genotype to a phenotype within the genetic algorithm framework.