Module expression

Module expression 

Structs

MetricQuery
SelectExpr
Selects one statistic from a named metric in a [MetricSet].

Enums

Expr
MetricField
Which statistic to extract from a metric in a [MetricSet].
MetricKind
How the extracted statistic should be wrapped. Value returns it as an f32 (or u64 for count/generation/update_count); Duration reinterprets the f32 as seconds.

Traits

Evaluate
ExprSelector