pub struct AlterResult(pub usize, pub Option<Vec<Metric>>, pub Option<Vec<LineageUpdate>>);Expand description
The AlterResult struct is used to represent the result of an alteration operation. It contains the number of operations performed and a vector of metrics that were collected during the alteration process.
Tuple Fields
0: usize1: Option<Vec<Metric>>2: Option<Vec<LineageUpdate>>Implementations
Sourceimpl AlterResult
impl AlterResult
pub fn empty() -> Self
pub fn count(&self) -> usize
pub fn update_lineage(&mut self, lineage: impl Into<LineageUpdate>)
pub fn merge(&mut self, other: AlterResult)