Struct HammingDistance

pub struct HammingDistance;
A concrete implementation of the Diversity trait that calculates the Hamming distance between two Genotypes. The Hamming distance is the number of positions at which the corresponding genes are different normalized by the total number of genes.