Structs
- Command
Channel - MutCell
- Wait
Group - Wait
Guard - Work
Result - WorkResult is a simple wrapper around a
Receiverthat allows the user to get the result of a job that was executed in the thread pool. It kinda acts like aFuturein a synchronous way.