pub struct FloatGene<F: Float> { /* private fields */ }Expand description
Minimum and maximum values for the FloatGene allele.
This should be large enough to cover most practical use cases
but small enough to avoid overflow or underflow issues in calculations.
1e18 = 1 quintillion
A Gene that represents a floating point number.
The allele is the in the case of the FloatGene a f32. The min and max values
default to [MIN] and [MAX] respectively. The min and max values are used to
generate a random number between the min and max values, which is the allele of the FloatGene.
The upper_bound and lower_bound are used to set the bounds of the FloatGene when it is used
in a BoundGene context (crossover or mutation). The upper_bound and lower_bound
default to [MAX] and [MIN] respectively.
Example
use radiate_core::*;
// Create a new FloatGene with a min value of 0 and a max value of 1 meaning the
// allele will be a random number between 0 and 1.
// The upper_bound and lower_bound are set to 0 and 1 respectively.
let gene = FloatGene::from(0_f32..1_f32);
// Create a new FloatGene with a min of 0 and a max of 1 and set the upper_bound
// and lower_bound to 0 and 100 respectively.
let gene = FloatGene::from((0_f32..1_f32, 0_f32..100_f32));Implementations