Structs
- Engine
Problem - EngineProblem is a generic, base level concrete implementation of the Problem trait that is the default problem used by the engine if none other is specified during building. We take the Codec and the fitness function from the user and simply wrap them into this struct.