Module rate
radiate_
core
1.2.21
Module rate
Module Items
Enums
In crate radiate_
core
radiate_core
Module
rate
Enums

Cycle
Shape
Rate
Rate enum representing different types of rate schedules where each variant defines a method to compute the rate value at a given step. These are designed to produce values within the range [0.0, 1.0] - ie: a rate.