Replacement strategy that replaces the individual with a new one generated by the encoder.
This is the default replacement strategy used in genetic algorithms.
Replacement strategy that replaces the individual with a random member of the population.
This can be useful in cases where the population is large and diverse or when the
chromosome grows or changes in size, thus encoding a new individual can result
in a member that that lacks significant diversity.