Structs
- Metric
Query - Select
Expr - Selects one statistic from a named metric in a [
MetricSet].
Enums
- Expr
- Metric
Field - Which statistic to extract from a metric in a [
MetricSet]. - Metric
Kind - How the extracted statistic should be wrapped.
Valuereturns it as anf32(oru64for count/generation/update_count);Durationreinterprets the f32 as seconds.